@@ -25,25 +25,28 @@
 
 #include <KConfigGroup>
 
-namespace Wacom {
+namespace Wacom
+{
 /**
-  * Private class for the d-pointer.
-  */
-class TabletDatabasePrivate {
+ * Private class for the d-pointer.
+ */
+class TabletDatabasePrivate
+{
 public:
-    QString locaDbFile;    //!< the filename (without path) of the local tablet database file
-    QString companyFile;   //!< the filename (without path) of the company configuration file
+    QString locaDbFile; //!< the filename (without path) of the local tablet database file
+    QString companyFile; //!< the filename (without path) of the company configuration file
     QString dataDirectory; //!< optional path to the data directory, used for unit tests
 };
 }
 
 using namespace Wacom;
 
-TabletDatabase::TabletDatabase() : d_ptr (new TabletDatabasePrivate)
+TabletDatabase::TabletDatabase()
+    : d_ptr(new TabletDatabasePrivate)
 {
-    Q_D (TabletDatabase);
-    d->locaDbFile = QLatin1String ("tabletdblocalrc");
-    d->companyFile = QLatin1String ("companylist");
+    Q_D(TabletDatabase);
+    d->locaDbFile = QLatin1String("tabletdblocalrc");
+    d->companyFile = QLatin1String("companylist");
 }
 
 TabletDatabase::~TabletDatabase()
@@ -51,17 +54,13 @@ TabletDatabase::~TabletDatabase()
     delete this->d_ptr;
 }
 
-
-
-TabletDatabase& TabletDatabase::instance()
+TabletDatabase &TabletDatabase::instance()
 {
     static TabletDatabase instance;
     return instance;
 }
 
-
-
-QString TabletDatabase::lookupBackend(const QString& companyId) const
+QString TabletDatabase::lookupBackend(const QString &companyId) const
 {
     KSharedConfig::Ptr companyConfig;
 
@@ -69,7 +68,7 @@ QString TabletDatabase::lookupBackend(const QString& companyId) const
         return QString();
     }
 
-    KConfigGroup companyGroup = KConfigGroup (companyConfig, companyId.toLower());
+    KConfigGroup companyGroup = KConfigGroup(companyConfig, companyId.toLower());
 
     if (companyGroup.keyList().isEmpty()) {
         qCInfo(COMMON) << QString::fromLatin1("Company with id '%1' could not be found in the tablet information database!").arg(companyId);
@@ -79,20 +78,20 @@ QString TabletDatabase::lookupBackend(const QString& companyId) const
     return companyGroup.readEntry("driver");
 }
 
-bool TabletDatabase::lookupTablet(const QString& tabletId, const QString& companyId, TabletInformation& tabletInfo) const
+bool TabletDatabase::lookupTablet(const QString &tabletId, const QString &companyId, TabletInformation &tabletInfo) const
 {
     KSharedConfig::Ptr companyConfig;
 
     KConfigGroup companyGroup;
     KConfigGroup tabletGroup;
-    QString      tabletsConfigFile;
+    QString tabletsConfigFile;
 
     if (!openCompanyConfig(companyConfig)) {
         return false;
     }
 
     // get company group section
-    companyGroup = KConfigGroup (companyConfig, companyId.toLower());
+    companyGroup = KConfigGroup(companyConfig, companyId.toLower());
 
     // get tablet database configuration file for this company
     tabletsConfigFile = companyGroup.readEntry("listfile");
@@ -103,17 +102,17 @@ bool TabletDatabase::lookupTablet(const QString& tabletId, const QString& compan
     }
 
     // lookup tablet
-    if (lookupTabletGroup (tabletsConfigFile, tabletId, tabletGroup)) {
+    if (lookupTabletGroup(tabletsConfigFile, tabletId, tabletGroup)) {
         // found tablet
-        getInformation (tabletGroup, tabletId, companyId, companyGroup.readEntry("name"), tabletInfo);
-        getButtonMap (tabletGroup, tabletInfo);
+        getInformation(tabletGroup, tabletId, companyId, companyGroup.readEntry("name"), tabletInfo);
+        getButtonMap(tabletGroup, tabletInfo);
         return true;
     }
 
     return false;
 }
 
-bool TabletDatabase::lookupTablet(const QString& tabletId, TabletInformation& tabletInfo) const
+bool TabletDatabase::lookupTablet(const QString &tabletId, TabletInformation &tabletInfo) const
 {
     KSharedConfig::Ptr companyConfig;
 
@@ -126,20 +125,17 @@ bool TabletDatabase::lookupTablet(const QString& tabletId, TabletInformation& ta
 
     // first check the localdb
     // here we support only Wacom tablet at the moment
-    Q_D (const TabletDatabase);
-    if (lookupTabletGroup(d->locaDbFile, tabletId, tabletGroup) ) {
+    Q_D(const TabletDatabase);
+    if (lookupTabletGroup(d->locaDbFile, tabletId, tabletGroup)) {
         // found tablet
         getInformation(tabletGroup, tabletId, QLatin1String("056a"), QLatin1String("Wacom Co., Ltd"), tabletInfo);
         getButtonMap(tabletGroup, tabletInfo);
         return true;
-    }
-    else {
+    } else {
         qCInfo(COMMON) << QString::fromLatin1("tablet %1 not in local db").arg(tabletId);
     }
 
-
-
-    foreach(const QString &companyId, companyConfig->groupList()) {
+    foreach (const QString &companyId, companyConfig->groupList()) {
         if (lookupTablet(tabletId, companyId, tabletInfo)) {
             return true;
         }
@@ -148,25 +144,21 @@ bool TabletDatabase::lookupTablet(const QString& tabletId, TabletInformation& ta
     return false;
 }
 
-
-
-void TabletDatabase::setDatabase(const QString& dataDirectory, const QString& companyFileName)
+void TabletDatabase::setDatabase(const QString &dataDirectory, const QString &companyFileName)
 {
-    Q_D (TabletDatabase);
+    Q_D(TabletDatabase);
     d->dataDirectory = dataDirectory;
-    d->companyFile   = companyFileName;
+    d->companyFile = companyFileName;
 }
 
-
-
-bool TabletDatabase::getButtonMap(const KConfigGroup& deviceGroup, TabletInformation& tabletInfo) const
+bool TabletDatabase::getButtonMap(const KConfigGroup &deviceGroup, TabletInformation &tabletInfo) const
 {
-    QMap<QString,QString> buttonMap;
-    int                   buttonNum = 1;
-    QString               buttonKey = QLatin1String("hwbutton1");
+    QMap<QString, QString> buttonMap;
+    int buttonNum = 1;
+    QString buttonKey = QLatin1String("hwbutton1");
 
-    while(deviceGroup.hasKey(buttonKey)) {
-        buttonMap.insert( QString::number(buttonNum), deviceGroup.readEntry(buttonKey));
+    while (deviceGroup.hasKey(buttonKey)) {
+        buttonMap.insert(QString::number(buttonNum), deviceGroup.readEntry(buttonKey));
         buttonKey = QString::fromLatin1("hwbutton%1").arg(++buttonNum);
     }
 
@@ -178,36 +170,36 @@ bool TabletDatabase::getButtonMap(const KConfigGroup& deviceGroup, TabletInforma
     return false;
 }
 
-
-
-bool TabletDatabase::getInformation(const KConfigGroup& deviceGroup, const QString& tabletId, const QString& companyId, const QString& companyName, TabletInformation& tabletInfo) const
+bool TabletDatabase::getInformation(const KConfigGroup &deviceGroup,
+                                    const QString &tabletId,
+                                    const QString &companyId,
+                                    const QString &companyName,
+                                    TabletInformation &tabletInfo) const
 {
     // tabletId, companyId & companyName are passed as parameter so all
     // tablet information data is set in one place and not all over this class.
 
     // get general information
-    tabletInfo.set (TabletInfo::TabletId,      tabletId.toUpper());
-    tabletInfo.set (TabletInfo::CompanyId,     companyId.toUpper());
-    tabletInfo.set (TabletInfo::CompanyName,   companyName);
-    tabletInfo.set (TabletInfo::TabletModel,   deviceGroup.readEntry ("model"));
-    tabletInfo.set (TabletInfo::TabletName,    deviceGroup.readEntry ("name"));
-    tabletInfo.set (TabletInfo::ButtonLayout,  deviceGroup.readEntry ("layout"));
-    tabletInfo.set (TabletInfo::NumPadButtons, deviceGroup.readEntry ("padbuttons"));
-    tabletInfo.set (TabletInfo::StatusLEDs,    deviceGroup.readEntry ("statusleds", QString::number(0)));
-    tabletInfo.set (TabletInfo::TouchSensorId, deviceGroup.readEntry ("touchsensorid"));
-    tabletInfo.set (TabletInfo::IsTouchSensor, deviceGroup.readEntry ("istouchsensor"));
+    tabletInfo.set(TabletInfo::TabletId, tabletId.toUpper());
+    tabletInfo.set(TabletInfo::CompanyId, companyId.toUpper());
+    tabletInfo.set(TabletInfo::CompanyName, companyName);
+    tabletInfo.set(TabletInfo::TabletModel, deviceGroup.readEntry("model"));
+    tabletInfo.set(TabletInfo::TabletName, deviceGroup.readEntry("name"));
+    tabletInfo.set(TabletInfo::ButtonLayout, deviceGroup.readEntry("layout"));
+    tabletInfo.set(TabletInfo::NumPadButtons, deviceGroup.readEntry("padbuttons"));
+    tabletInfo.set(TabletInfo::StatusLEDs, deviceGroup.readEntry("statusleds", QString::number(0)));
+    tabletInfo.set(TabletInfo::TouchSensorId, deviceGroup.readEntry("touchsensorid"));
+    tabletInfo.set(TabletInfo::IsTouchSensor, deviceGroup.readEntry("istouchsensor"));
 
-    tabletInfo.setBool (TabletInfo::HasLeftTouchStrip,  deviceGroup.readEntry ("touchstripl"));
-    tabletInfo.setBool (TabletInfo::HasRightTouchStrip, deviceGroup.readEntry ("touchstripr"));
-    tabletInfo.setBool (TabletInfo::HasTouchRing,       deviceGroup.readEntry ("touchring"));
-    tabletInfo.setBool (TabletInfo::HasWheel,           deviceGroup.readEntry ("wheel"));
+    tabletInfo.setBool(TabletInfo::HasLeftTouchStrip, deviceGroup.readEntry("touchstripl"));
+    tabletInfo.setBool(TabletInfo::HasRightTouchStrip, deviceGroup.readEntry("touchstripr"));
+    tabletInfo.setBool(TabletInfo::HasTouchRing, deviceGroup.readEntry("touchring"));
+    tabletInfo.setBool(TabletInfo::HasWheel, deviceGroup.readEntry("wheel"));
 
     return true;
 }
 
-
-
-bool TabletDatabase::lookupTabletGroup(const QString& tabletsConfigFile, const QString& tabletId, KConfigGroup& tabletGroup) const
+bool TabletDatabase::lookupTabletGroup(const QString &tabletsConfigFile, const QString &tabletId, KConfigGroup &tabletGroup) const
 {
     // open the device list file
     KSharedConfig::Ptr tabletConfig;
@@ -217,7 +209,7 @@ bool TabletDatabase::lookupTabletGroup(const QString& tabletsConfigFile, const Q
     }
 
     // lookup device
-    tabletGroup = KConfigGroup (tabletConfig, tabletId.toUpper());
+    tabletGroup = KConfigGroup(tabletConfig, tabletId.toUpper());
 
     if (tabletGroup.keyList().isEmpty()) {
         return false;
@@ -226,16 +218,14 @@ bool TabletDatabase::lookupTabletGroup(const QString& tabletsConfigFile, const Q
     return true;
 }
 
-
-
-bool TabletDatabase::openConfig(const QString& configFileName, KSharedConfig::Ptr& configFile) const
+bool TabletDatabase::openConfig(const QString &configFileName, KSharedConfig::Ptr &configFile) const
 {
-    Q_D( const TabletDatabase );
+    Q_D(const TabletDatabase);
 
     QString configFilePath;
 
     if (d->dataDirectory.isEmpty()) {
-        configFilePath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QString::fromLatin1 ("wacomtablet/data/%1").arg(configFileName));
+        configFilePath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QString::fromLatin1("wacomtablet/data/%1").arg(configFileName));
     } else {
         configFilePath = QString::fromLatin1("%1/%2").arg(d->dataDirectory).arg(configFileName);
     }
@@ -249,7 +239,7 @@ bool TabletDatabase::openConfig(const QString& configFileName, KSharedConfig::Pt
         return false;
     }
 
-    configFile = KSharedConfig::openConfig (configFilePath, KConfig::SimpleConfig, QStandardPaths::GenericDataLocation);
+    configFile = KSharedConfig::openConfig(configFilePath, KConfig::SimpleConfig, QStandardPaths::GenericDataLocation);
 
     if (configFile->groupList().isEmpty()) {
         qCWarning(COMMON) << QString::fromLatin1("Tablet database configuration file '%1' is empty or not readable!").arg(configFilePath);
@@ -259,11 +249,9 @@ bool TabletDatabase::openConfig(const QString& configFileName, KSharedConfig::Pt
     return true;
 }
 
-
-
-bool TabletDatabase::openCompanyConfig(KSharedConfig::Ptr& configFile) const
+bool TabletDatabase::openCompanyConfig(KSharedConfig::Ptr &configFile) const
 {
-    Q_D (const TabletDatabase);
+    Q_D(const TabletDatabase);
 
     QString configFileName;
 
